// mijdbctest2.java
//
// tests user defined types
//
// Erwin Kalvelagen, TNO FEL
// Copyright (c) 1996 Bradley McLean / Jeffrey Medeiros
//
// You may distribute under the terms of the GNU Public License as
// specified in the README file that comes with the JavaPostgres95 Kit

import java.sql.*;
import java.math.*;
import java.io.*;
import mijdbc.*;


class box2 {
  float x1,y1,x2,y2;
  
  box2(float x1, float y1, float x2, float y2) {
    this.x1 = x1;
    this.y1 = y1;
    this.x2 = x2;
    this.y2 = y2;
  }

 public  String toString() {
    return "[("+x1+","+y1+")-("+x2+","+y2+")]";
  }
}

class mijdbctest2 {

   public static void main(String argv[]) {
      try {

	// explicit instantiation of the Driver
	// handy during development: forces recompile
	// of changed mijdbc sources.
	Driver mid = (Driver) new mijdbc.MIDriver();
	// in other cases one would use a late binding:
	//Class.forName( "mijdbc.MIDriver" );

			
	String url = "jdbc:mijdbc://134.203.33.12:7532/erwin";
	
	//java.util.Properties info = new java.util.Properties();
	//info.addProperty("user","emfh7");
	//info.addProperty("password","");

	Connection conn = DriverManager.getConnection(url,"emfh7","");
	
	Statement stat = conn.createStatement();

	// BOX2 test ---------------------------------------------

  
	exec(stat,"create table mijdbctest (b BOX2);");
	exec(stat,"insert into mijdbctest values ('(1,2,3,4)');");
	test_userdeftype(stat,"select * from mijdbctest;");
	exec(stat,"drop table mijdbctest;");


	conn.close();

      } catch ( Exception e ) {
         System.err.println("E: "+e);
	 e.printStackTrace();
      }
   }

  private static void exec(Statement stat, String s) throws SQLException {
    
    int updatecount;
    
    try {
      System.out.println(s);
      stat.execute(s);
      updatecount = stat.getUpdateCount();
      System.out.println("  update count= "+updatecount);
      if (updatecount == -1) {
	ResultSet rs = stat.getResultSet(); 
	if (rs == null) 
	  System.out.println("resultset is null!");
	else 
	  displayResults(rs);
      }
      
    } catch (Exception e) {
      throw new SQLException(""+e);
    }
    
    
  }
  

  private static void displayResults(ResultSet rs) throws SQLException {

    int i;
    int rowcnt = 0;


    try {
      
      
      ResultSetMetaData rsmd = rs.getMetaData();
      
      int numcols = rsmd.getColumnCount();
      System.out.println("  column count= "+numcols);

      System.out.print("  column names= ");
      for (i=1; i<=numcols; ++i) {
	if (i>1) System.out.print(", ");
	System.out.print(rsmd.getColumnName(i));
      }
      System.out.println("");

      System.out.print("  column types= ");
      for (i=1; i<=numcols; ++i) {
	if (i>1) System.out.print(", ");
	System.out.print(rsmd.getColumnTypeName(i));
      }
      System.out.println("");

 
      while (rs.next()) {
	
	System.out.print("  row "+ (++rowcnt) + "= ");
	for (i=1; i<=numcols; ++i) {
	  if (i>1) System.out.print(", ");
	  System.out.print(rs.getString(i));
	}
	System.out.println("");	

      }
     
    } catch (Exception e) {
      throw new SQLException(""+e);
    }
  }

  private static void test_userdeftype(Statement stat, String qs) {

    try {

      
      System.out.println(qs);
      stat.execute(qs);

      int updatecount = stat.getUpdateCount();
      System.out.println("  update count= "+updatecount);
      
      ResultSet rs = stat.getResultSet();
      ResultSetMetaData rsmd = rs.getMetaData();
      
      int numcols = rsmd.getColumnCount();


      if (rs.next())
	for (int i=1; i<=numcols; ++i) {
	  
	  System.out.println("Illustra column type: "+ rsmd.getColumnTypeName(i));
	  

          if (rsmd.getColumnTypeName(i).equals("BOX2")) {

	    DataInputStream is = new DataInputStream(rs.getBinaryStream(i));

	    float x1,y1,x2,y2;
	    x1 = is.readFloat();
	    y1 = is.readFloat();
	    x2 = is.readFloat();
	    y2 = is.readFloat();

	    box2 b2 = new box2(x1,y1,x2,y2);

	    System.out.println("Box2="+b2);
	    
	  }

	}
      
      
      
    } catch (Exception e) {
      System.out.println(""+e);
    }
    
      

  }

}



